@@ -43,8 +43,10 @@
 #include <QDebug>
 
 #include <DRecentManager>
+#include <DDialog>
 
 DCORE_USE_NAMESPACE
+DWIDGET_USE_NAMESPACE
 
 class RecentFileWatcherPrivate;
 class RecentFileWatcher : public DAbstractFileWatcher
@@ -174,7 +176,7 @@ void RecentFileWatcher::removeWatcher(const DUrl &url)
 }
 
 void RecentFileWatcher::onFileDeleted(const DUrl &url)
-{    
+{
     DUrl newUrl = url;
     newUrl.setScheme(RECENT_SCHEME);
     removeWatcher(newUrl);
@@ -324,8 +326,29 @@ bool RecentController::openFileLocation(const QSharedPointer<DFMOpenFileLocation
 
 bool RecentController::openFile(const QSharedPointer<DFMOpenFileEvent> &event) const
 {
+    //在smb/ftp更改文件名称后最近使用里面打开文件，使用createFileInfo不能判断源文件是否存在为真
+    //这里直接获取真实路径进行判断源文件是否存在
+    if (!QFile(event->url().path()).exists()) {
+        DDialog d(QObject::tr("Failed to open the file, cause: %1")
+                  .arg(QObject::tr("Original file does not exist")),
+                  QObject::tr("Do you want to delete %1?")
+                  .arg(event->url().fileName()));
+
+        Qt::WindowFlags flags = d.windowFlags();
+        // dialog show top
+        d.setWindowFlags(flags | Qt::CustomizeWindowHint | Qt::WindowStaysOnTopHint);
+        d.setIcon(QIcon::fromTheme("dialog-error"));
+        d.addButton(QObject::tr("Confirm","button"), true, DDialog::ButtonRecommend);
+        d.addButton(QObject::tr("Cancel","button"), false, DDialog::ButtonRecommend);
+        d.setMaximumWidth(640);
+        if(d.exec() == 0)
+            DRecentManager::removeItem(event->url().path());   //删除当前最近使用项
+        return true;
+    }
+
     return DFileService::instance()->openFile(event->sender(), DUrl::fromLocalFile(event->url().path()));
 }
+
 bool RecentController::openFiles(const QSharedPointer<DFMOpenFilesEvent> &event) const
 {
     DUrlList fileUrls = event->urlList();
@@ -439,22 +462,40 @@ bool RecentController::createSymlink(const QSharedPointer<DFMCreateSymlinkEvent>
 
 bool RecentController::deleteFiles(const QSharedPointer<DFMDeleteEvent> &event) const
 {
-    QStringList list;
-    for (const DUrl &url : event->urlList()) {
-        //list << DUrl::fromLocalFile(url.path()).toString();
-        //通过durl转换path会出现编码问题，这里直接用字符串拼出正确的path;
-        QString urlPath = url.path();
-        list << "file://" + urlPath;
-    }
+    DThreadUtil::runInMainThread([event] {
+        DDialog dlg;
+        dlg.setIcon(QIcon::fromTheme("dialog-warning"));
+        dlg.addButton(tr("Cancel", "button"));
+        dlg.addButton(tr("Remove", "button"), true, DDialog::ButtonRecommend);
 
-    DRecentManager::removeItems(list);
+        if (event->urlList().size() == 1)
+            dlg.setTitle(tr("Do you want to remove this item?"));
+        else
+            dlg.setTitle(tr("Do yout want to remove %1 items?").arg(event->urlList().size()));
+        dlg.setMessage(tr("It does not delete the original files"));
+
+        int code = dlg.exec();
+        if (code == 1) {
+            QStringList list;
+            for (const DUrl &url : event->urlList()) {
+                //list << DUrl::fromLocalFile(url.path()).toString();
+                //通过durl转换path会出现编码问题，这里直接用字符串拼出正确的path;
+                QString urlPath = url.path();
+                list << "file://" + urlPath;
+            }
+
+            DRecentManager::removeItems(list);
+        }
+    });
 
     return true;
 }
 
 DUrlList RecentController::moveToTrash(const QSharedPointer<DFMMoveToTrashEvent> &event) const
 {
-    DFileService::instance()->deleteFiles(event->sender(), event->urlList(), false, event->silent(), true);
+    deleteFiles(dMakeEventPointer<DFMDeleteEvent>(event->sender(),
+                                                  event->urlList(),
+                                                  event->silent()));
 
     return DUrlList();
 }
@@ -535,6 +576,8 @@ void RecentController::handleFileChanged()
         return;
     }
 
+    QPointer<RecentController> dp = this;
+
     if (m_condition.wait(&m_xbelFileLock, 1000)) {
         // if the parser is interrupted.
         // we need a timeout long enough so that
@@ -557,7 +600,9 @@ void RecentController::handleFileChanged()
             const QStringRef &readTime = reader.attributes().value("modified");
 
             if (!location.isEmpty()) {
-                DUrl url = DUrl(location.toString());
+                QString path = location.toString();
+                path = FileUtils::bindPathTransform(path);
+                DUrl url = DUrl(path);
                 QFileInfo info(url.toLocalFile());
                 DUrl recentUrl = url;
                 recentUrl.setScheme(RECENT_SCHEME);
@@ -566,7 +611,8 @@ void RecentController::handleFileChanged()
                     urlList << recentUrl;
 
                     DThreadUtil::runInMainThread([ = ]() {
-//                        RecentPointer fileInfo();
+                        if (dp.isNull())
+                            return;
                         // 保险箱内文件不显示到最近使用页面
                         if(!VaultController::isVaultFile(location.toString())) {
                             if (!recentNodes.contains(recentUrl)) {
@@ -590,10 +636,13 @@ void RecentController::handleFileChanged()
         }
     }
 
+    if (dp.isNull())
+        return;
     // delete does not exist url.
     for (auto iter = recentNodes.begin(); iter != recentNodes.end();) {
-        DUrl url = iter.key();
-
+        if (dp.isNull())
+            return;
+        const DUrl &url = iter.key();
         if (!urlList.contains(url)) {
             DThreadUtil::runInMainThread([this, &iter, url]() {
                 iter = recentNodes.erase(iter);
@@ -603,10 +652,16 @@ void RecentController::handleFileChanged()
                                                   url);
             });
         } else {
-            iter.value()->updateInfo();
-
-            ++iter;
+            auto info = iter.value();
+            if (info) {
+                iter.value()->updateInfo();
+                ++iter;
+            } else {
+                iter = recentNodes.erase(iter);
+            }
         }
+        if (dp.isNull())
+            return;
     }
 
     m_xbelFileLock.unlock();
