@@ -46,6 +46,7 @@
 #include "shutil/danythingmonitorfilter.h"
 #include "dfmapplication.h"
 #include "dfmstandardpaths.h"
+#include "plugins/pluginemblemmanager.h"
 
 #ifdef SW_LABEL
 #include "sw_label/filemanagerlibrary.h"
@@ -276,13 +277,13 @@ DFileInfoPrivate::DFileInfoPrivate(const DUrl &fileUrl, DFileInfo *qq, bool hasC
 DFileInfoPrivate::~DFileInfoPrivate()
 {
     if (getIconTimer) {
-        getIconTimer->disconnect(SIGNAL(timeout()));
+        getIconTimer->disconnect(SIGNAL(timeout())); // 导致指针析构问题,UT注意
         getIconTimer->stop();
         getIconTimer->deleteLater();
     }
 
     if (getEPTimer) {
-        getEPTimer->disconnect(SIGNAL(timeout()));
+        getEPTimer->disconnect(SIGNAL(timeout())); // 导致指针析构问题，UT注意
         getEPTimer->stop();
         getEPTimer->deleteLater();
     }
@@ -434,6 +435,9 @@ QList<QIcon> DFileInfo::additionalIcon() const
         icons << QIcon::fromTheme("emblem-shared", DFMGlobal::instance()->standardIcon(DFMGlobal::ShareIcon));
     }
 
+    // 记录系统角标的个数
+    int countOfSystemIcon = icons.count();
+
     //部分文件和目录不显示徽标
     if (needEmblem &&
             fileUrl().parentUrl().path() != "/" &&
@@ -448,6 +452,10 @@ QList<QIcon> DFileInfo::additionalIcon() const
     }
 #endif
 
+    // 添加插件角标
+    if (countOfSystemIcon < kMaxEmblemCount)
+        PluginEmblemManager::instance()->getPluginEmblemIconsFromMap(fileUrl(), countOfSystemIcon, icons);
+
     return icons;
 }
 
@@ -924,11 +932,11 @@ void DFileInfo::refresh(const bool isForce)
 
 DUrl DFileInfo::goToUrlWhenDeleted() const
 {
-    QString absFilePath = absoluteFilePath();
+    const QString &absFilePath = absoluteFilePath();
     if (deviceListener->isInDeviceFolder(absFilePath) ||
-            absFilePath.startsWith("/run/user" /*for gvfs mount point*/) ||
-            absFilePath.startsWith("/media/")) {
-        return DUrl::fromLocalFile(QDir::homePath());
+            absFilePath.startsWith("/run/user") // for gvfs mount point
+            || absFilePath.startsWith("/media/")) {
+        return DUrl(COMPUTER_ROOT);
     }
 
     return DAbstractFileInfo::goToUrlWhenDeleted();
@@ -1102,7 +1110,7 @@ QVariantHash DFileInfo::extraProperties() const
         const DUrl &url = fileUrl();
 
         if (!d->getEPTimer) {
-            d->getEPTimer = new QTimer();
+            d->getEPTimer = new QTimer(qApp);
             d->getEPTimer->setSingleShot(true);
             d->getEPTimer->moveToThread(qApp->thread());
             d->getEPTimer->setInterval(REQUEST_THUMBNAIL_DEALY);
@@ -1134,10 +1142,10 @@ quint64 DFileInfo::inode() const
     }
 
     struct stat statinfo;
-    int filestat = stat(d->fileInfo.absoluteFilePath().toStdString().c_str(), &statinfo);
-    if (filestat != 0) {
+    QByteArray pathArry = d->fileInfo.absoluteFilePath().toUtf8();
+    std::string pathStd = pathArry.toStdString();
+    if (stat(pathStd.c_str(), &statinfo) != 0)
         return 0;
-    }
     d->inode = statinfo.st_ino;
 
     return d->inode;
