@@ -247,6 +247,8 @@ bool DFileService::fmEvent(const QSharedPointer<DFMEvent> &event, QVariant *resu
 
             if (result.toBool()) {
                 emit fileRenamed(e->fromUrl(), e->toUrl());
+            } else {
+                DThreadUtil::runInMainThread(dialogManager, &DialogManager::showRenameBusyErrDialog, *event.data());
             }
         }
 
@@ -269,14 +271,14 @@ bool DFileService::fmEvent(const QSharedPointer<DFMEvent> &event, QVariant *resu
 
             const DAbstractFileInfoPointer &f = createFileInfo(this, durl);
             if (f && f->exists()) {
-                static bool lock = false;
                 // 如果传入的 event 中 silent 为 true，就不再弹框询问是否删除
                 auto delEvent = dynamic_cast<DFMDeleteEvent *>(event.data());
                 bool deleteFileSilently = delEvent && delEvent->silent();
-                if (!lock && (deleteFileSilently || DThreadUtil::runInMainThread(dialogManager, &DialogManager::showDeleteFilesClearTrashDialog, DFMUrlListBaseEvent(nullptr, event->fileUrlList())) == DDialog::Accepted)) {
-                    lock = true;
+                if (deleteFileSilently || DThreadUtil::runInMainThread(dialogManager, &DialogManager::showDeleteFilesClearTrashDialog, DFMUrlListBaseEvent(nullptr, event->fileUrlList())) == DDialog::Accepted) {
+                    // 这里已经确认删除了，同次调用走静默删除，避免二次弹窗
+                    if (delEvent)
+                        delEvent->setProperty(QT_STRINGIFY(DFMDeleteEvent::silent), true);
                     result = CALL_CONTROLLER(deleteFiles);
-                    lock = false;
                     if (result.toBool()) {
                         for (const DUrl &r : event->fileUrlList()) {
                             emit fileDeleted(r);
@@ -284,18 +286,9 @@ bool DFileService::fmEvent(const QSharedPointer<DFMEvent> &event, QVariant *resu
                     }
                 }
 
-                if (lock) {
-                    result = CALL_CONTROLLER(deleteFiles);
-                    if (result.toBool()) {
-                        for (const DUrl &r : event->fileUrlList()) {
-                            emit fileDeleted(r);
-                        }
-                    }
-                } else {
-                    //fix bug 31324,判断当前操作是否是清空回收站，是就在结束时改变清空回收站状态
-                    if (event->fileUrlList().count() == 1 && event->fileUrlList().first().toString() == TRASH_ROOT) {
-                        setDoClearTrashState(false);
-                    }
+                //fix bug 31324,判断当前操作是否是清空回收站，是就在结束时改变清空回收站状态
+                if (event->fileUrlList().count() == 1 && event->fileUrlList().first().toString() == TRASH_ROOT) {
+                    setDoClearTrashState(false);
                 }
 
                 break;
@@ -487,6 +480,18 @@ void DFileService::initHandlersByCreators()
     DFileServicePrivate::controllerCreatorHash.clear();
 }
 
+void DFileService::clearController(const QString &scheme, const QString &host)
+{
+    const HandlerType &type = HandlerType(scheme, host);
+    auto controllers = DFileServicePrivate::controllerHash.values(type);
+    for (auto controller : controllers) {
+        DFileServicePrivate::handlerHash.remove(controller);
+        DFileServicePrivate::controllerHash.remove(type, controller);
+        delete controller;
+        controller = nullptr;
+    }
+}
+
 DFileService *DFileService::instance()
 {
     static DFileService services;
@@ -639,7 +644,9 @@ DUrlList DFileService::moveToTrash(const QObject *sender, const DUrlList &list)
     }
     //end
 
-    if (FileUtils::isGvfsMountFile(list.first().toLocalFile())) {
+    const QString& rootPath = list.first().toLocalFile();
+
+    if (!rootPath.isEmpty() && (FileUtils::isGvfsMountFile(rootPath) || deviceListener->isInRemovableDeviceFolder(rootPath) || VaultController::isVaultFile(rootPath))) {
         deleteFiles(sender, list);
         return list;
     }
@@ -678,6 +685,17 @@ void DFileService::pasteFileByClipboard(const QObject *sender, const DUrl &targe
     if (targetUrl.scheme() == SEARCH_SCHEME) {
         return;
     }
+    if (action == DFMGlobal::RemoteAction) {
+        qInfo() << "RemoteAction download remote files";
+        pasteFile(sender, action, targetUrl, DUrlList());
+        return;
+    }
+    // 远程协助
+    if (action == DFMGlobal::RemoteCopiedAction) {
+        qInfo() << "Remote Copy: set Current Url to Clipboard";
+        DFMGlobal::setCurUrlToClipboardForRemote(targetUrl);
+        return;
+    }
     const DUrlList &list = DUrl::fromQUrlList(DFMGlobal::instance()->clipboardFileUrlList());
 
     if (action == DFMGlobal::CutAction) {
@@ -704,7 +722,7 @@ void DFileService::pasteFileByClipboard(const QObject *sender, const DUrl &targe
 DUrlList DFileService::pasteFile(const QObject *sender, DFMGlobal::ClipboardAction action, const DUrl &targetUrl, const DUrlList &list) const
 {
     const QSharedPointer<DFMPasteEvent> &event = dMakeEventPointer<DFMPasteEvent>(sender, action, targetUrl, list);
-    const DUrlList &new_list = qvariant_cast<DUrlList>(DFMEventDispatcher::instance()->processEventWithEventLoop(event));
+    const DUrlList &new_list = qvariant_cast<DUrlList>(DFMEventDispatcher::instance()->processEvent(event));
 
     return new_list;
 }
@@ -1061,13 +1079,13 @@ bool DFileService::checkGvfsMountfileBusy(const DUrl &rootUrl, const QString &ro
 
     if (rootFileName.startsWith(SMB_SCHEME) || rootFileName.startsWith(SFTP_SCHEME)) {
         DAbstractFileInfoPointer rootptr = createFileInfo(nullptr, rootUrl);
-        bool fileexit = rootptr->exists();
+        bool fileExists = rootptr->exists();
         setCursorBusyState(false);
         //文件不存在弹提示框
-        if (!fileexit && bShowDailog) {
+        if (!fileExists && bShowDailog && FileUtils::isNetworkUrlMounted(rootUrl)) {
             dialogManager->showUnableToLocateDir(rootFileName);
         }
-        return !fileexit;
+        return !fileExists;
     }
 
     //是网络文件，就去确定host和port端口号
@@ -1087,12 +1105,12 @@ bool DFileService::checkGvfsMountfileBusy(const DUrl &rootUrl, const QString &ro
         port = ipInfoList[1].replace("port=", "");
     }
 
-    bvist = d->m_checknetwork.isHostAndPortConnect(host, port);
+    bvist = d->m_checknetwork.isHostAndPortConnect(host, port.toUShort() <= 0 ? QString("21") : port);
 
     setCursorBusyState(false);
 
     //文件不存在弹提示框
-    if (!bvist && bShowDailog) {
+    if (!bvist && bShowDailog && FileUtils::isNetworkUrlMounted(rootUrl)) {
         dialogManager->showUnableToLocateDir(rootFileName);
     }
     qDebug() << bvist;
