@@ -53,10 +53,13 @@
 #include "dfmsettings.h"
 #include "bluetooth/bluetoothmanager.h"
 #include "drootfilemanager.h"
+#include "plugins/schemepluginmanager.h"
+#include "extensionimpl/dfmextpluginmanager.h"
+#include "plugins/pluginemblemmanager.h"
 
 #include <DArrowRectangle>
 
-#include <QGuiApplication>
+#include <QApplication>
 #include <QClipboard>
 #include <QMimeData>
 #include <QIcon>
@@ -74,6 +77,9 @@
 #include <QDBusObjectPath>
 #include <QRegularExpression>
 #include <QPainterPath>
+#include <QMutex>
+#include <QMimeType>
+#include <QMimeDatabase>
 
 #include <private/qtextengine_p.h>
 
@@ -82,13 +88,13 @@
 #include <sstream>
 #include <fstream>
 #include <sys/stat.h>
+#include <mutex>
 
 #include <KCodecs>
 #include <KEncodingProber>
 #include <DSysInfo>
 
-#include <QMimeType>
-#include <QMimeDatabase>
+#include <X11/Xlib.h>
 
 DWIDGET_USE_NAMESPACE;
 
@@ -103,18 +109,37 @@ extern "C"
 }
 #endif //__cplusplus
 
+#define CURRENT_URL_KEY "uos/remote-copied-files"
+
 namespace GlobalData {
 static QList<QUrl> clipboardFileUrls;
+static QMutex clipboardFileUrlsMutex;
 static QList<quint64> clipbordFileinode;
+static QAtomicInt remoteCurrentCount = 0;
 static DFMGlobal::ClipboardAction clipboardAction = DFMGlobal::UnknowAction;
 
 void onClipboardDataChanged()
 {
-    clipboardFileUrls.clear();
+    {
+        QMutexLocker lk(&clipboardFileUrlsMutex);
+        clipboardFileUrls.clear();
+    }
     clipbordFileinode.clear();
     const QMimeData *mimeData = qApp->clipboard()->mimeData();
-    if (!mimeData) {
-        qWarning() << "get null mimeData from QClipBoard!";
+    if (!mimeData || mimeData->formats().isEmpty()) {
+        qWarning() << "get null mimeData from QClipBoard or remote formats is null!";
+        return;
+    }
+    if (mimeData->hasFormat("uos/remote-copy")) {
+        qInfo() << "clipboard use other !";
+        clipboardAction = DFMGlobal::RemoteAction;
+        remoteCurrentCount++;
+        return;
+    }
+    // 远程协助功能
+    if (mimeData->hasFormat(CURRENT_URL_KEY)) {
+        qInfo() << "Remote copy: set remote copy action";
+        clipboardAction = DFMGlobal::RemoteCopiedAction;
         return;
     }
     const QByteArray &data = mimeData->data("x-special/gnome-copied-files");
@@ -130,8 +155,10 @@ void onClipboardDataChanged()
     for (QUrl &_url : mimeData->urls()) {
         if (_url.scheme().isEmpty())
             _url.setScheme("file");
-
-        clipboardFileUrls << _url;
+        {
+            QMutexLocker lk(&clipboardFileUrlsMutex);
+            clipboardFileUrls << _url;
+        }
         //链接文件的inode不加入clipbordFileinode，只用url判断clip，避免多个同源链接文件的逻辑误判
         const DAbstractFileInfoPointer &fileInfo = DFileService::instance()->createFileInfo(nullptr, DUrl(_url));
         if (!fileInfo || fileInfo->isSymLink())
@@ -266,6 +293,25 @@ void DFMGlobal::setUrlsToClipboard(const QList<QUrl> &list, DFMGlobal::Clipboard
     qApp->clipboard()->setMimeData(mimeData);
 }
 
+void DFMGlobal::setCurUrlToClipboardForRemote(const DUrl &curUrl)
+{
+    if (!curUrl.isValid())
+        return;
+    QByteArray localPath;
+    if (curUrl.isLocalFile()) {
+        localPath = curUrl.toString().toLocal8Bit();
+    } else {
+        qInfo() << "Remote copy: current url not local file";
+        return;
+    }
+
+    if (localPath.isEmpty())
+        return;
+    QMimeData *mimeData = new QMimeData();
+    mimeData->setData(CURRENT_URL_KEY, localPath);
+    qApp->clipboard()->setMimeData(mimeData);
+}
+
 const QList<QUrl> DFMGlobal::fetchUrlsFromClipboard()
 {
     if (qApp->clipboard()) {
@@ -331,6 +377,12 @@ void DFMGlobal::initPluginManager()
     refreshPlugins();
 }
 
+//NOTE [XIAO] DFMGlobal::initSchemePluginManager
+void DFMGlobal::initSchemePluginManager()
+{
+    SchemePluginManager::instance()->loadSchemePlugin();
+}
+
 void DFMGlobal::initSearchHistoryManager()
 {
     searchHistoryManager;
@@ -523,6 +575,12 @@ void DFMGlobal::initRootFileManager()
     rootFileManager;
 }
 
+void DFMGlobal::initEmblemPluginManagerConnection()
+{
+    connect(PluginEmblemManager::instance(), &PluginEmblemManager::updatePluginEmblem,
+            fileSignalManager, &FileSignalManager::requestUpdateAllFileView);
+}
+
 QString DFMGlobal::getUser()
 {
     static QString user = QString::fromLocal8Bit(qgetenv("USER"));
@@ -577,6 +635,11 @@ bool DFMGlobal::isDeveloperMode()
     return developerModel;
 }
 
+bool DFMGlobal::isProfessional()
+{
+    return DSysInfo::deepinType() == DSysInfo::DeepinProfessional;
+}
+
 QList<QUrl> DFMGlobal::clipboardFileUrlList() const
 {
     return GlobalData::clipboardFileUrls;
@@ -1126,6 +1189,35 @@ bool DFMGlobal::fileNameCorrection(const QByteArray &filePath)
     return std::rename(filePath.constData(), newFilePath.constData());
 }
 
+bool DFMGlobal::autoInitExtPluginManager()
+{
+    if (DFMExtPluginManager::instance().state() == DFMExtPluginManager::State::Invalid) {
+        qInfo() << "extPluginPath:" << DFMExtPluginManager::instance().pluginPaths();
+        DFMExtPluginManager::instance().scanPlugins();
+        qInfo() << "extPlugin scanned all plugin";
+    }
+
+    if (DFMExtPluginManager::instance().state() == DFMExtPluginManager::State::Scanned) {
+        DFMExtPluginManager::instance().loadPlugins();
+        qInfo() << "extPlugin loaded all plugin";
+    }
+
+    if (DFMExtPluginManager::instance().state() == DFMExtPluginManager::State::Loaded) {
+        DFMExtPluginManager::instance().initPlugins();
+        qInfo() << "extPlugin initialized all plugin";
+    }
+
+    if (DFMExtPluginManager::instance().state() == DFMExtPluginManager::State::Initialized) {
+       if (!DFMExtPluginManager::instance().monitorPlugins()) {
+           qWarning() << "init plugin monitor failed!";
+           return false;
+       }
+        qInfo() << "extPlugin initialization has been successful!";
+    }
+
+    return true;
+}
+
 bool DFMGlobal::isDesktopFile(const DUrl &url)
 {
     return url.toLocalFile().endsWith(".desktop");
@@ -1163,27 +1255,11 @@ bool DFMGlobal::isComputerDesktopFileUrl(const DUrl &url)
     return false;
 }
 
-//! 限制wayland判断次数
-static int wayland = 0;
-//! 保存是否是wayland平台
-static bool isWland = false;
 bool DFMGlobal::isWayLand()
 {
-    if (wayland > 0) {
-        return isWland;
-    } else {
-        auto e = QProcessEnvironment::systemEnvironment();
-        QString XDG_SESSION_TYPE = e.value(QStringLiteral("XDG_SESSION_TYPE"));
-        QString WAYLAND_DISPLAY = e.value(QStringLiteral("WAYLAND_DISPLAY"));
-
-        //在wayland平台下设置固定大小，解决属性框最大化问题
-        if (XDG_SESSION_TYPE == QLatin1String("wayland") ||
-                WAYLAND_DISPLAY.contains(QLatin1String("wayland"), Qt::CaseInsensitive)) {
-            isWland = true;
-        }
-        wayland = 1;
-    }
-    return isWland;
+    //! 该函数只能在QApplication之后调用才能返回有效的值，在此之前会返回空值
+    Q_ASSERT(qApp);
+    return QApplication::platformName() == "wayland";
 }
 
 void DFMGlobal::showMultiFilesRenameDialog(const QList<DUrl> &selectedFiles)
@@ -1250,6 +1326,158 @@ bool DFMGlobal::isAppQuiting()
     return IsAppQuiting.load();
 }
 
+
+QList<QUrl> DFMGlobal::getUrlsByX11()
+{
+    QAtomicInt currentCount = GlobalData::remoteCurrentCount;
+    const QMimeData *mimedata = qApp->clipboard()->mimeData();
+    if (!mimedata) {
+        qWarning() << "the clipboard mimedata is invalid!";
+        return QList<QUrl>();
+    }
+    if (GlobalData::clipboardAction != RemoteAction) {
+        qWarning() << "current action is not RemoteAction ,error action " << GlobalData::clipboardAction;
+        return QList<QUrl>();
+    }
+    //使用x11创建一个窗口去阻塞获取URl
+    Display *display = XOpenDisplay(nullptr);
+    unsigned long color = BlackPixel(display, DefaultScreen(display));
+    Window window = XCreateSimpleWindow(display, DefaultRootWindow(display), 0,0, 1,1, 0, color, color);
+
+    char *result = nullptr;
+    unsigned long ressize = 0, restail = 0;
+    int resbits;
+    Atom bufid = XInternAtom(display, "CLIPBOARD", False),
+         fmtid = XInternAtom(display, "text/uri-list", False),
+         propid = XInternAtom(display, "XSEL_DATA", False),
+         incrid = XInternAtom(display, "INCR", False);
+    XEvent event;
+
+    QList<QUrl> urls;
+    QString results;
+    QAtomicInteger<bool> isCanceled = false;
+
+    XSelectInput (display, window, PropertyChangeMask);
+    XConvertSelection(display, bufid, fmtid, propid, window, CurrentTime);
+    do {
+      XNextEvent(display, &event);
+    } while (event.type != SelectionNotify || event.xselection.selection != bufid);
+    if (event.xselection.property) {
+        XGetWindowProperty(display, window, propid, 0, LONG_MAX/4, True, AnyPropertyType,
+                           &fmtid, &resbits, &ressize, &restail, (unsigned char**)&result);
+        if (fmtid != incrid) {
+           qInfo() << QString(result);
+           urls += QUrl::fromStringList(QString(result).split("\n"));
+        }
+
+        XFree(result);
+
+        if (fmtid == incrid) {
+            do {
+                do {
+                    XNextEvent(display, &event);
+                    if (event.type == SelectionNotify) {
+                        isCanceled = true;
+                        break;
+                    }
+                } while (event.type != PropertyNotify || event.xproperty.atom != propid || event.xproperty.state != PropertyNewValue);
+                if (isCanceled)
+                    break;
+                XGetWindowProperty(display, window, propid, 0, LONG_MAX/4, True, AnyPropertyType, &fmtid, &resbits, &ressize, &restail, (unsigned char**)&result);
+                if (QString(result) != "/")
+                    results += QString(result);
+                XFree(result);
+            } while (ressize > 0);
+        }
+    }
+    XDestroyWindow(display, window);
+    XCloseDisplay(display);
+
+    if (isCanceled) {
+        qWarning() << "user cancel remote download !";
+        return QList<QUrl>();
+    }
+    urls += QUrl::fromStringList(results.split("\n"));
+
+    QList<QUrl> clipboardFileUrls;
+    for (QUrl url : urls) {
+        //链接文件的inode不加入clipbordFileinode，只用url判断clip，避免多个同源链接文件的逻辑误判
+        if (url.toString() == "copy")
+            continue;
+
+        QString path = url.path();
+        path = path.replace(QRegExp("/*/"),"/");
+        if (path.isEmpty() || path == "/")
+            continue;
+        QUrl temp;
+        temp.setScheme("file");
+        temp.setPath(path);
+        clipboardFileUrls << temp;
+    }
+    qInfo() << results << urls << clipboardFileUrls;
+
+    if (GlobalData::clipboardAction == RemoteAction && currentCount == GlobalData::remoteCurrentCount) {
+        QMutexLocker lk(&GlobalData::clipboardFileUrlsMutex);
+        GlobalData::clipboardFileUrls.clear();
+        GlobalData::clipboardFileUrls = clipboardFileUrls;
+        GlobalData::clipboardAction = CopyAction;
+        GlobalData::remoteCurrentCount = 0;
+    }
+
+    return clipboardFileUrls;
+}
+
+QList<QUrl> DFMGlobal::getUrlsByQt()
+{
+    QAtomicInt currentCount = GlobalData::remoteCurrentCount;
+    const QMimeData *mimedata = qApp->clipboard()->mimeData();
+    if (!mimedata) {
+        qWarning() << "the clipboard mimedata is invalid!";
+        return QList<QUrl>();
+    }
+    if (GlobalData::clipboardAction != RemoteAction) {
+        qWarning() << "current action is not RemoteAction ,error action " << GlobalData::clipboardAction;
+        return QList<QUrl>();
+    }
+
+    QList<QUrl> urls = mimedata->urls();
+
+    QList<QUrl> clipboardFileUrls;
+    for (QUrl url : urls) {
+        //链接文件的inode不加入clipbordFileinode，只用url判断clip，避免多个同源链接文件的逻辑误判
+        if (url.toString() == "copy")
+            continue;
+
+        QString path = url.path();
+        path = path.replace(QRegExp("/*/"),"/");
+        if (path.isEmpty() || path == "/")
+            continue;
+        QUrl temp;
+        temp.setScheme("file");
+        temp.setPath(path);
+        clipboardFileUrls << temp;
+    }
+
+    qInfo() << urls << clipboardFileUrls;
+
+    if (GlobalData::clipboardAction == RemoteAction && currentCount == GlobalData::remoteCurrentCount) {
+        QMutexLocker lk(&GlobalData::clipboardFileUrlsMutex);
+        GlobalData::clipboardFileUrls.clear();
+        GlobalData::clipboardFileUrls = clipboardFileUrls;
+        GlobalData::clipboardAction = CopyAction;
+        GlobalData::remoteCurrentCount = 0;
+    }
+
+    return clipboardFileUrls;
+}
+
+QList<QUrl> DFMGlobal::getRemoteUrls()
+{
+    if (isWayLand())
+        return getUrlsByQt();
+    return getUrlsByX11();
+}
+
 QString DFMGlobal::toUnicode(const QByteArray &data, const QString &fileName)
 {
     if (data.isEmpty())
@@ -1314,6 +1542,7 @@ FunctionCallProxy::FunctionCallProxy(QThread *thread)
 {
     connect(this, &FunctionCallProxy::callInLiveThread, this, [](FunctionType * func) {
         (*func)();
+        delete func;
     }, Qt::QueuedConnection);
     connect(thread, &QThread::finished, this, [this] {
         qWarning() << sender() << "the thread finished";
