@@ -86,7 +86,7 @@ public:
     static QString newDocmentName(QString targetdir, const QString &baseName, const QString &suffix);
     static bool cpTemplateFileToTargetDir(const QString &targetdir, const QString &baseName, const QString &suffix, WId windowId);
 
-    static bool openFile(const QString &filePath);
+    static bool openFile(const QString &filePath, const QString &desktopFile = QString());
     static bool openFiles(const QStringList &filePaths);
     static bool openEnterFiles(const QStringList &filePaths);
     static bool launchApp(const QString &desktopFile, const QStringList &filePaths = {}); // open filePaths by desktopFile
@@ -143,6 +143,11 @@ public:
     static bool isDesktopFile(const QFileInfo &fileInfo, QMimeType &mimetyp);
     static void addRecentFile(const QString &filePath, const DesktopFile &desktopFile, const QString &mimetype);
 
+    static bool isContainProhibitPath(const QList<QUrl> &urls);
+    static bool isContainProhibitPath(const QUrl &url);
+
+    static QStringList fstabProhibitPaths(const QStringList &usrProhibitPaths);
+
     // 启用deepin-compressor追加压缩
     static bool appendCompress(const DUrl &toUrl, const DUrlList &fromUrlList);
     //获取内存叶大小
