@@ -37,20 +37,16 @@
 #include <QProcess>
 
 OperatorCenter::OperatorCenter(QObject *parent)
-    : QObject(parent)
-    , m_strCryfsPassword("")
-    , m_strUserKey("")
-    , m_standOutput("")
+    : QObject(parent), m_strCryfsPassword(""), m_strUserKey(""), m_standOutput("")
 {
-
 }
 
 QString OperatorCenter::makeVaultLocalPath(const QString &before, const QString &behind)
 {
     return VAULT_BASE_PATH
-//            + QDir::separator() + CONFIG_DIR_NAME
-           + (before.isEmpty() ? QString("") : QDir::separator()) + before
-           + (behind.isEmpty() ? QString("") : QDir::separator()) + behind;
+            //            + QDir::separator() + CONFIG_DIR_NAME
+            + (before.isEmpty() ? QString("") : QDir::separator()) + before
+            + (behind.isEmpty() ? QString("") : QDir::separator()) + behind;
 }
 
 bool OperatorCenter::runCmd(const QString &cmd)
@@ -97,7 +93,7 @@ bool OperatorCenter::executeProcess(const QString &cmd)
     return runCmd(newCmd);
 }
 
-bool OperatorCenter::secondSaveSaltAndCiphertext(const QString &ciphertext, const QString &salt)
+bool OperatorCenter::secondSaveSaltAndCiphertext(const QString &ciphertext, const QString &salt, const char *vaultVersion)
 {
     // 密文
     QString strCiphertext = pbkdf2::pbkdf2EncrypyPassword(ciphertext, salt, ITERATION_TWO, PASSWORD_CIPHER_LENGTH);
@@ -108,7 +104,92 @@ bool OperatorCenter::secondSaveSaltAndCiphertext(const QString &ciphertext, cons
     VaultConfig config;
     config.set(CONFIG_NODE_NAME, CONFIG_KEY_CIPHER, QVariant(strSaltAndCiphertext));
     // 更新保险箱版本信息
-    config.set(CONFIG_NODE_NAME, CONFIG_KEY_VERSION, QVariant(CONFIG_VAULT_VERSION));
+    config.set(CONFIG_NODE_NAME, CONFIG_KEY_VERSION, QVariant(vaultVersion));
+
+    return true;
+}
+
+bool OperatorCenter::createKeyNew(const QString &password)
+{
+    m_strPubKey.clear();
+    QString strPriKey("");
+    rsam::createPublicAndPrivateKey(m_strPubKey, strPriKey);
+
+    // 私钥加密
+    QString strCipher = rsam::privateKeyEncrypt(password, strPriKey);
+
+    // 验证公钥长度
+    if (m_strPubKey.length() < 2 * USER_KEY_INTERCEPT_INDEX + 32) {
+        qDebug() << "USER_KEY_LENGTH is to long!";
+        m_strPubKey.clear();
+        return false;
+    }
+
+    // 保存密文
+    QString strCipherFilePath = makeVaultLocalPath(RSA_CIPHERTEXT_FILE_NAME);
+    QFile cipherFile(strCipherFilePath);
+    if (!cipherFile.open(QIODevice::Text | QIODevice::WriteOnly | QIODevice::Truncate)) {
+        qDebug() << "open rsa cipher file failure!";
+        return false;
+    }
+    QTextStream out2(&cipherFile);
+    out2 << strCipher;
+    cipherFile.close();
+
+    return true;
+}
+
+bool OperatorCenter::saveKey(QString key, QString path)
+{
+    // 保存部分公钥
+    QString publicFilePath = path;
+    QFile publicFile(publicFilePath);
+    if (!publicFile.open(QIODevice::Text | QIODevice::WriteOnly | QIODevice::Truncate)) {
+        qDebug() << "open public key file failure!";
+        return false;
+    }
+    publicFile.setPermissions(QFileDevice::ReadOwner | QFileDevice::WriteOwner | QFileDevice::ReadGroup);
+    QTextStream out(&publicFile);
+    out << key;
+    publicFile.close();
+    return true;
+}
+
+QString OperatorCenter::getPubKey()
+{
+    return m_strPubKey;
+}
+
+bool OperatorCenter::verificationRetrievePassword(const QString keypath, QString &password)
+{
+    QFile localPubKeyfile(keypath);
+    if (!localPubKeyfile.open(QIODevice::Text | QIODevice::ReadOnly)) {
+        qDebug() << "cant't open local public key file!";
+        return false;
+    }
+
+    QString strLocalPubKey(localPubKeyfile.readAll());
+    localPubKeyfile.close();
+
+    // 利用完整公钥解密密文，得到密码
+    QString strRSACipherFilePath = makeVaultLocalPath(RSA_CIPHERTEXT_FILE_NAME);
+    QFile rsaCipherfile(strRSACipherFilePath);
+    if (!rsaCipherfile.open(QIODevice::Text | QIODevice::ReadOnly)) {
+        qDebug() << "cant't open rsa cipher file!";
+        return false;
+    }
+
+    QString strRsaCipher(rsaCipherfile.readAll());
+    rsaCipherfile.close();
+
+    password = rsam::publicKeyDecrypt(strRsaCipher, strLocalPubKey);
+
+    // 判断密码的正确性，如果密码正确，则用户密钥正确，否则用户密钥错误
+    QString temp = "";
+    if (!checkPassword(password, temp)) {
+        qDebug() << "user key error!";
+        return false;
+    }
 
     return true;
 }
@@ -136,31 +217,47 @@ bool OperatorCenter::createDirAndFile()
         }
     }
 
-    // 创建存放rsa公钥的文件
+    // 创建配置文件,并设置文件权限
+    QString strConfigFilePath = strConfigDir + QDir::separator() + VAULT_CONFIG_FILE_NAME;
+    QFile configFile(strConfigFilePath);
+    if (!configFile.exists()) {
+        // 如果文件不存在，则创建文件，并设置权限
+        if (configFile.open(QFileDevice::WriteOnly | QFileDevice::Text)) {
+            configFile.setPermissions(QFileDevice::ReadOwner | QFileDevice::WriteOwner | QFileDevice::ReadGroup);
+            configFile.close();
+        } else {
+            qInfo() << "保险箱：创建配置文件失败！";
+        }
+    }
+
+    // 创建存放rsa公钥的文件,并设置文件权限
     QString strPriKeyFile = makeVaultLocalPath(RSA_PUB_KEY_FILE_NAME);
     QFile prikeyFile(strPriKeyFile);
     if (!prikeyFile.open(QIODevice::WriteOnly | QIODevice::Append)) {
         qDebug() << "create rsa private key file failure!";
         return false;
     }
+    prikeyFile.setPermissions(QFileDevice::ReadOwner | QFileDevice::WriteOwner | QFileDevice::ReadGroup);
     prikeyFile.close();
 
-    // 创建存放rsa公钥加密后密文的文件
+    // 创建存放rsa公钥加密后密文的文件,并设置文件权限
     QString strRsaCiphertext = makeVaultLocalPath(RSA_CIPHERTEXT_FILE_NAME);
     QFile rsaCiphertextFile(strRsaCiphertext);
     if (!rsaCiphertextFile.open(QIODevice::WriteOnly | QIODevice::Append)) {
         qDebug() << "create rsa ciphertext file failure!";
         return false;
     }
+    rsaCiphertextFile.setPermissions(QFileDevice::ReadOwner | QFileDevice::WriteOwner | QFileDevice::ReadGroup);
     rsaCiphertextFile.close();
 
-    // 创建密码提示信息文件
+    // 创建密码提示信息文件,并设置文件权限
     QString strPasswordHintFilePath = makeVaultLocalPath(PASSWORD_HINT_FILE_NAME);
     QFile passwordHintFile(strPasswordHintFilePath);
-    if (!passwordHintFile.open(QIODevice::WriteOnly | QIODevice:: Append)) {
+    if (!passwordHintFile.open(QIODevice::WriteOnly | QIODevice::Append)) {
         qDebug() << "create password hint file failure!";
         return false;
     }
+    passwordHintFile.setPermissions(QFileDevice::ReadOwner | QFileDevice::WriteOwner | QFileDevice::ReadGroup);
     passwordHintFile.close();
 
     return true;
@@ -177,7 +274,7 @@ bool OperatorCenter::saveSaltAndCiphertext(const QString &password, const QStrin
     QString strSaltAndCiphertext = strRandomSalt + strCiphertext;
 
     // 保存第二次加密后的密文,并更新保险箱版本信息
-    secondSaveSaltAndCiphertext(strSaltAndCiphertext, strRandomSalt);
+    secondSaveSaltAndCiphertext(strSaltAndCiphertext, strRandomSalt, CONFIG_VAULT_VERSION_1050);
 
     // 保存密码提示信息
     QString strPasswordHintFilePath = makeVaultLocalPath(PASSWORD_HINT_FILE_NAME);
@@ -252,7 +349,7 @@ bool OperatorCenter::checkPassword(const QString &password, QString &cipher)
     VaultConfig config;
     QString strVersion = config.get(CONFIG_NODE_NAME, CONFIG_KEY_VERSION).toString();
 
-    if (CONFIG_VAULT_VERSION == strVersion) {   // 如果是新版本，验证第二次加密的结果
+    if ((CONFIG_VAULT_VERSION == strVersion) || (CONFIG_VAULT_VERSION_1050 == strVersion)) {   // 如果是新版本，验证第二次加密的结果
         // 获得本地盐及密文
         QString strSaltAndCipher = config.get(CONFIG_NODE_NAME, CONFIG_KEY_CIPHER).toString();
         QString strSalt = strSaltAndCipher.mid(0, RANDOM_SALT_LENGTH);
@@ -266,10 +363,10 @@ bool OperatorCenter::checkPassword(const QString &password, QString &cipher)
 
         if (strCipher != strNewCipher2) {
             qDebug() << "password error!";
-            return  false;
+            return false;
         }
         cipher = strNewSaltAndCipher;
-    } else {    // 如果是旧版本，验证第一次加密的结果
+    } else {   // 如果是旧版本，验证第一次加密的结果
         // 获得本地盐及密文
         QString strfilePath = makeVaultLocalPath(PASSWORD_FILE_NAME);
         QFile file(strfilePath);
@@ -287,13 +384,13 @@ bool OperatorCenter::checkPassword(const QString &password, QString &cipher)
         QString strNewSaltAndCipher = strSalt + strNewCipher;
         if (strNewSaltAndCipher != strSaltAndCipher) {
             qDebug() << "password error!";
-            return  false;
+            return false;
         }
 
         cipher = strNewSaltAndCipher;
 
         // 保存第二次加密后的密文,并更新保险箱版本信息
-        if (!secondSaveSaltAndCiphertext(strNewSaltAndCipher, strSalt)) {
+        if (!secondSaveSaltAndCiphertext(strNewSaltAndCipher, strSalt, CONFIG_VAULT_VERSION)) {
             qDebug() << "第二次加密密文失败！";
             return false;
         }
@@ -308,7 +405,7 @@ bool OperatorCenter::checkUserKey(const QString &userKey, QString &cipher)
 {
     if (userKey.length() != USER_KEY_LENGTH) {
         qDebug() << "user key length error!";
-        return  false;
+        return false;
     }
 
     // 结合本地公钥和用户密钥，还原完整公钥
@@ -405,7 +502,6 @@ bool OperatorCenter::createQRCode(const QString &srcStr, int width, int height,
 
     pix = QPixmap::fromImage(mainimg);
 
-
     if (qrcode)
         QRcode_free(qrcode);
     return true;
@@ -488,7 +584,7 @@ QString OperatorCenter::autoGeneratePassword(int length)
 bool OperatorCenter::getRootPassword()
 {
     // 判断当前是否是管理员登陆
-    bool res = runCmd("id -un");  // file path is fixed. So write cmd direct
+    bool res = runCmd("id -un");   // file path is fixed. So write cmd direct
     if (res && m_standOutput.trimmed() == "root") {
         return true;
     }
@@ -518,8 +614,8 @@ int OperatorCenter::executionShellCommand(const QString &strCmd, QStringList &ls
         qDebug() << QString("popen error: %s").arg(strerror(errno));
         return -1;
     } else {
-        char buf[MAXLINE] = {'\0'};
-        while (fgets(buf, sizeof(buf), fp)) { // 获得每行输出
+        char buf[MAXLINE] = { '\0' };
+        while (fgets(buf, sizeof(buf), fp)) {   // 获得每行输出
             QString strLineOutput(buf);
             if (strLineOutput.endsWith('\n'))
                 strLineOutput.chop(1);
@@ -538,4 +634,3 @@ int OperatorCenter::executionShellCommand(const QString &strCmd, QStringList &ls
         }
     }
 }
-
