@@ -149,6 +149,14 @@ DFileDialog::DFileDialog(QWidget *parent)
     // 文件对话框只能在本窗口打开新目录
     if (d_ptr->view) {
         d_ptr->view->setAlwaysOpenInCurrentWindow(true);
+        DFileSystemModel *model = d_ptr->view->model();
+        if (model) {
+            connect(model, &DFileSystemModel::stateChanged, this, [model](DFileSystemModel::State state){
+                if (state == DFileSystemModel::Idle && (model->effectFilters() != model->filters())) {
+                    model->refresh();
+                }
+            });
+        }
     }
 
     setWindowFlags(Qt::WindowCloseButtonHint | Qt::WindowTitleHint | Qt::Dialog);
@@ -484,9 +492,8 @@ void DFileDialog::selectNameFilterByIndex(int index)
                 return getFileView()->setNameFilters(newNameFilters); //这里传递回去的有可能是一个正则表达式，它决定哪些文件不被置灰
             }
         }
-//        下面这部分内容似乎没有必要，因为上面已经查询到了第一个符合QMimeDataBase记录的扩展名
-//        newNameFilterExtension = db.suffixForFileName(newNameFilters.at(0));
-
+        if (!newNameFilters.isEmpty())
+            newNameFilterExtension = db.suffixForFileName(newNameFilters.at(0));
         if (!fileNameExtension.isEmpty() && !newNameFilterExtension.isEmpty()) {
             const int fileNameExtensionLength = fileNameExtension.count();
             fileName.replace(fileName.count() - fileNameExtensionLength,
