@@ -166,6 +166,8 @@ public:
     // 设置总是在当前窗口打开子目录
     void setAlwaysOpenInCurrentWindow(bool openInCurrentWindow);
 
+    int verticalOffset() const override;
+
 public slots:
     bool cd(const DUrl &url);
     bool cdUp();
@@ -246,6 +248,7 @@ protected slots:
 protected:
     void wheelEvent(QWheelEvent *event) override;
     void keyPressEvent(QKeyEvent *event) override;
+    void keyReleaseEvent(QKeyEvent *event) override;
     void showEvent(QShowEvent *event) override;
     void mousePressEvent(QMouseEvent *event) override;
     void mouseMoveEvent(QMouseEvent *event) override;
@@ -266,6 +269,7 @@ protected:
     bool event(QEvent *e) override;
     void updateGeometries() override;
     bool eventFilter(QObject *obj, QEvent *event) override;
+    void paintEvent(QPaintEvent *e) override;
 
 #if QT_CONFIG(draganddrop)
     void startDrag(Qt::DropActions supportedActions) override;
@@ -331,6 +335,11 @@ private:
      */
     void setTargetUrlToApp(const QMimeData *data, const DUrl &url);
 
+    void showCustomDragPixmap(const QModelIndexList &indexes, Qt::DropActions supportedActions);
+    void setViewSelectState(bool bSelect);
+
+    bool bShowViewSelectBox { false };
+
     bool m_isRemovingCase = false;
     QScopedPointer<DFileViewPrivate> d_ptr;
     QList<QUrl> m_urlsForDragEvent;
