@@ -401,7 +401,7 @@ void DFMSideBar::rootFileResult()
                 if (r == devitems.end()) {
                     this->addItem(DFMSideBarDeviceItemHandler::createItem(url), this->groupName(Device));
                     devitems.append(url);
-                } else {
+                } else if (r > devitems.begin() && r < devitems.end()) {
                     this->insertItem(this->findLastItem(this->groupName(Device)) - (devitems.end() - r) + 1, DFMSideBarDeviceItemHandler::createItem(url), this->groupName(Device));
                     devitems.insert(r, url);
                 }
@@ -412,6 +412,8 @@ void DFMSideBar::rootFileResult()
 
 void DFMSideBar::onItemActivated(const QModelIndex &index)
 {
+    if(!DRootFileManager::instance()->isRootFileInited())
+        return;
     DFMSideBarItem *item = m_sidebarModel->itemFromIndex(index);
     QString identifierStr = item->registeredHandler(SIDEBAR_ID_INTERNAL_FALLBACK);
 
