@@ -3,6 +3,8 @@
 #include <QProcess>
 #include <QSharedPointer>
 #include <QDebug>
+#include <QDBusMessage>
+#include <QDBusReply>
 
 #include "interfaces/dfilesystemmodel.h"
 #include "testhelper.h"
