@@ -61,6 +61,7 @@ public:
 
 TEST_F(TestDFMVaultFileView, tst_setRootUrl)
 {
+<<<<<<< HEAD   (ea7281 fix: 回退代码（该提交分支为临时测试分支）)
     auto closeWindow = [](DUrl & url) {
         VaultController::VaultState enState = VaultController::ins()->state();
         if (enState != VaultController::Unlocked) {
@@ -70,7 +71,6 @@ TEST_F(TestDFMVaultFileView, tst_setRootUrl)
                 break;
             }
             case VaultController::NotExisted: {
-                DFMVaultActiveView::getInstance()->close();
                 break;
             }
             case VaultController::Encrypted: {
@@ -91,6 +91,9 @@ TEST_F(TestDFMVaultFileView, tst_setRootUrl)
         }
     };
 
+=======
+    // 对exec函数打桩
+>>>>>>> CHANGE (88ddfd fix: 文管选择框弹出保险箱的窗口，导致文管崩溃问题)
     Stub stl;
     typedef int(*fptr)(QDialog*);
     fptr pQDialogExec = (fptr)(&QDialog::exec);
@@ -99,18 +102,27 @@ TEST_F(TestDFMVaultFileView, tst_setRootUrl)
     stl.set(pQDialogExec, stub_DDialog_exec);
     stl.set(pDDialogExec, stub_DDialog_exec);
 
+    // 对DFMVaultPageBase::showTop()函数打桩
+    void(*stub_showTop1)() = [](){};
+    Stub stub2;
+    typedef void(*fptr1)();
+    fptr1 pShowTop1 = (fptr1)(&DFMVaultPageBase::showTop);
+    stub2.set(pShowTop1, stub_showTop1);
+
+    // 对DFMVaultRemovePages::showTop()
+    void(*stub_showTop2)() = [](){};
+    Stub stub3;
+    fptr1 pShowTop2 = (fptr1)(&DFMVaultRemovePages::showTop);
+    stub3.set(pShowTop2, stub_showTop2);
+
     DUrl url = VaultController::makeVaultUrl();
     EXPECT_NO_FATAL_FAILURE(m_view->setRootUrl(url));
 
-    closeWindow(url);
-
     url.setHost("delete");
     EXPECT_NO_FATAL_FAILURE(m_view->setRootUrl(url));
-    closeWindow(url);
 
     url.setHost("certificate");
     EXPECT_NO_FATAL_FAILURE(m_view->setRootUrl(url));
-    closeWindow(url);
 
     // replace VaultController::state
     VaultController::VaultState(*st_state)(QString lockBaseDir) =
@@ -121,7 +133,6 @@ TEST_F(TestDFMVaultFileView, tst_setRootUrl)
     Stub stub;
     stub.set(ADDR(VaultController, state), st_state);
     EXPECT_NO_FATAL_FAILURE(m_view->setRootUrl(url));
-    closeWindow(url);
 
     stub.reset(ADDR(VaultController, state));
     url.setHost("delete");
@@ -135,7 +146,6 @@ TEST_F(TestDFMVaultFileView, tst_setRootUrl)
     stub.set(ADDR(VaultController, state), st_state_unLocked);
 
     EXPECT_NO_FATAL_FAILURE(m_view->setRootUrl(url));
-    closeWindow(url);
 
     // replace VaultController::state
     VaultController::VaultState(*st_state_encrypted)(QString lockBaseDir) =
@@ -146,7 +156,6 @@ TEST_F(TestDFMVaultFileView, tst_setRootUrl)
     stub.set(ADDR(VaultController, state), st_state_encrypted);
 
     EXPECT_NO_FATAL_FAILURE(m_view->setRootUrl(url));
-    closeWindow(url);
 }
 
 TEST_F(TestDFMVaultFileView, tst_onLeaveVault)
